@@ -38,11 +38,6 @@ wall_clock::tic()
     chrono_time1 = std::chrono::steady_clock::now();
     valid = true;
     }
-  #elif defined(ARMA_USE_BOOST_DATE)
-    {
-    boost_time1 = boost::posix_time::microsec_clock::local_time();
-    valid = true;
-    }
   #elif defined(ARMA_HAVE_GETTIMEOFDAY)
     {
     gettimeofday(&posix_time1, 0);
@@ -76,11 +71,6 @@ wall_clock::toc()
       
       return chrono_span.count();
       }
-    #elif defined(ARMA_USE_BOOST_DATE)
-      {
-      boost_duration = boost::posix_time::microsec_clock::local_time() - boost_time1;
-      return boost_duration.total_microseconds() * 1e-6;
-      }
     #elif defined(ARMA_HAVE_GETTIMEOFDAY)
       {
       gettimeofday(&posix_time2, 0);
